@@ -6,7 +6,7 @@ from functools import lru_cache
 import redis
 
 from . import conf
-from .utils import get_redis_connection
+from .utils import get_redis_connection, get_signature
 
 
 @lru_cache(maxsize=None)
@@ -19,6 +19,7 @@ class RedisLiveHandler(logging.Handler):
         fmt = logging.Formatter(conf.SMART_LOG_FORMAT)
         return json.dumps(
             {
+                "__sender__": get_signature(),
                 "name": record.name,
                 "levelname": record.levelname,
                 "levelno": record.levelno,
