@@ -7,7 +7,7 @@ from django.urls import reverse
 
 @pytest.mark.django_db
 def test_panel_no_online(app, settings, monkeypatch):
-    monkeypatch.setattr("smart_logging.forms.conf.SMART_LOG_ONLINE", False)
+    monkeypatch.setattr("smart_logging.forms.conf.SMART_LOG_INSPECT", False)
     url = reverse("admin:smart_logging_panel")
     assert app.get(url)
 
